@@ -1,4 +1,5 @@
 """ Factory to build WebDrivers. """
+from pylenium import driver
 from typing import List, Optional
 
 from selenium import webdriver
@@ -81,7 +82,10 @@ def build_options(browser,
         raise ValueError(f'{browser} is not supported. https://elsnoman.gitbook.io/pylenium/configuration/driver')
 
     for option in browser_options:
-        options.add_argument(f'--{option}')
+        if option.startswith('--'):
+            options.add_argument(option)
+        else:
+            options.add_argument(f'--{option}')
 
     if experimental_options:
         for exp_option in experimental_options:
@@ -111,15 +115,42 @@ def build_from_config(config: PyleniumConfig) -> WebDriver:
         )
     browser = config.driver.browser.lower()
     if browser == Browser.CHROME:
-        return build_chrome(config.driver.version, config.driver.options, config.driver.experimental_options, config.driver.extension_paths)
+        return build_chrome(
+            config.driver.version,
+            config.driver.options,
+            config.driver.experimental_options,
+            config.driver.extension_paths,
+            config.driver.local_path)
     elif browser == Browser.FIREFOX:
-        return build_firefox(config.driver.version, config.driver.options, config.driver.experimental_options, config.driver.extension_paths)
+        return build_firefox(
+            config.driver.version,
+            config.driver.options,
+            config.driver.experimental_options,
+            config.driver.extension_paths,
+            config.driver.local_path)
     elif browser == Browser.IE:
-        return build_ie(config.driver.version, config.driver.options, config.driver.capabilities, config.driver.experimental_options, config.driver.extension_paths)
+        return build_ie(
+            config.driver.version,
+            config.driver.options,
+            config.driver.capabilities,
+            config.driver.experimental_options,
+            config.driver.extension_paths,
+            config.driver.local_path)
     elif browser == Browser.OPERA:
-        return build_opera(config.driver.version, config.driver.options, config.driver.experimental_options, config.driver.extension_paths)
+        return build_opera(
+            config.driver.version,
+            config.driver.options,
+            config.driver.experimental_options,
+            config.driver.extension_paths,
+            config.driver.local_path)
     elif browser == Browser.EDGE:
-        return build_edge(config.driver.version, config.driver.options, config.driver.capabilities, config.driver.experimental_options, config.driver.extension_paths)
+        return build_edge(
+            config.driver.version,
+            config.driver.options,
+            config.driver.capabilities,
+            config.driver.experimental_options,
+            config.driver.extension_paths,
+            config.driver.local_path)
     else:
         raise ValueError(f'{config.driver.browser} is not supported. https://elsnoman.gitbook.io/pylenium/configuration/driver')
 
@@ -127,7 +158,8 @@ def build_from_config(config: PyleniumConfig) -> WebDriver:
 def build_chrome(version: str,
                  browser_options: List[str],
                  experimental_options: Optional[List[dict]],
-                 extension_paths: Optional[List[str]]) -> WebDriver:
+                 extension_paths: Optional[List[str]],
+                 local_path: Optional[str]) -> WebDriver:
     """ Build a ChromeDriver.
 
     Args:
@@ -135,11 +167,14 @@ def build_chrome(version: str,
         browser_options: The list of options/arguments to include.
         experimental_options: The list of experimental options to include.
         extension_paths: The list of extensions to add to the browser.
+        local_path: The path to the driver binary.
 
     Examples:
         driver = WebDriverFactory().build_chrome('latest', ['headless', 'incognito'], None)
     """
     options = build_options(Browser.CHROME, browser_options, experimental_options, extension_paths)
+    if local_path:
+        return webdriver.Chrome(local_path, options=options)
     return webdriver.Chrome(ChromeDriverManager(version=version).install(), options=options)
 
 
@@ -147,7 +182,8 @@ def build_edge(version: str,
                browser_options: List[str],
                capabilities: dict,
                experimental_options: Optional[List[dict]],
-               extension_paths: Optional[List[str]]) -> WebDriver:
+               extension_paths: Optional[List[str]],
+               local_path: Optional[str]) -> WebDriver:
     """ Build a Edge Driver.
 
     Args:
@@ -156,6 +192,7 @@ def build_edge(version: str,
         capabilities: The dict of capabilities to include.
         experimental_options: The list of experimental options to include.
         extension_paths: The list of extensions to add to the browser.
+        local_path: The path to the driver binary.
 
     Examples:
         driver = WebDriverFactory().build_edge('latest', ['headless', 'incognito'], None)
@@ -163,13 +200,16 @@ def build_edge(version: str,
     caps = build_capabilities(Browser.EDGE, capabilities)
     options = build_options(Browser.EDGE, browser_options, experimental_options, extension_paths).to_capabilities()
     caps.update(options)
+    if local_path:
+        return webdriver.Edge(local_path, capabilities=caps)
     return webdriver.Edge(EdgeChromiumDriverManager(version=version).install(),  capabilities=caps)
 
 
 def build_firefox(version: str,
                   browser_options: List[str],
                   experimental_options: Optional[List[dict]],
-                  extension_paths: Optional[List[str]]) -> WebDriver:
+                  extension_paths: Optional[List[str]],
+                  local_path: Optional[str]) -> WebDriver:
     """ Build a FirefoxDriver.
 
     Args:
@@ -177,11 +217,14 @@ def build_firefox(version: str,
         browser_options: The list of options/arguments to include.
         experimental_options: The list of experimental options to include.
         extension_paths: The list of extensions to add to the browser.
+        local_path: The path to the driver binary.
 
     Examples:
         driver = WebDriverFactory().build_firefox('latest', ['headless', 'incognito'], None)
     """
     options = build_options(Browser.FIREFOX, browser_options, experimental_options, extension_paths)
+    if local_path:
+        return webdriver.Firefox(executable_path=local_path, options=options)
     return webdriver.Firefox(executable_path=GeckoDriverManager(version=version).install(), options=options)
 
 
@@ -189,7 +232,8 @@ def build_ie(version: str,
              browser_options: List[str],
              capabilities: dict,
              experimental_options: Optional[List[dict]],
-             extension_paths: Optional[List[str]]) -> WebDriver:
+             extension_paths: Optional[List[str]],
+             local_path: Optional[str]) -> WebDriver:
     """ Build an IEDriver.
 
     Args:
@@ -198,19 +242,23 @@ def build_ie(version: str,
         capabilities: The dict of capabilities.
         experimental_options: The list of experimental options to include.
         extension_paths: The list of extensions to add to the browser.
+        local_path: The path to the driver binary.
 
     Examples:
         driver = WebDriverFactory().build_ie('latest', ['headless'], None)
     """
     caps = build_capabilities(Browser.IE, capabilities)
     options = build_options(Browser.IE, browser_options, experimental_options, extension_paths)
+    if local_path:
+        return webdriver.Ie(executable_path=local_path, options=options, capabilities=caps)
     return webdriver.Ie(executable_path=IEDriverManager(version=version).install(), options=options, capabilities=caps)
 
 
 def build_opera(version: str,
                 browser_options: List[str],
                 experimental_options: Optional[List[dict]],
-                extension_paths: Optional[List[str]]) -> WebDriver:
+                extension_paths: Optional[List[str]],
+                local_path: Optional[str]) -> WebDriver:
     """ Build an OperaDriver.
 
     Args:
@@ -218,11 +266,14 @@ def build_opera(version: str,
         browser_options: The list of options/arguments to include.
         experimental_options: The list of experimental options to include.
         extension_paths: The list of extensions to add to the browser.
+        local_path: The path to the driver binary.
 
     Examples:
         driver = WebDriverFactory().build_opera('latest', ['--start-maximized'], None)
     """
     options = build_options(Browser.OPERA, browser_options, experimental_options, extension_paths)
+    if local_path:
+        return webdriver.Opera(executable_path=local_path, options=options)
     return webdriver.Opera(executable_path=OperaDriverManager(version=version).install(), options=options)
 
 
